@@ -52,6 +52,12 @@ pub enum Error {
     OpenLogFile(io::Error),
     PromptAborted,
     NoMoreEvents,
+    CannotSpinoffCurrentBranch,
+    SpinoffBranchExists(String),
+    DoesBranchExist(git2::Error),
+    GetBranchName(git2::Error),
+    BaseCommitOid,
+    UpstreamCommitOid,
 }
 
 impl std::error::Error for Error {}
@@ -146,6 +152,18 @@ impl Display for Error {
             Error::OpenLogFile(e) => f.write_fmt(format_args!("Couldn't open log file: {e}")),
             Error::PromptAborted => f.write_str("Aborted"),
             Error::NoMoreEvents => unimplemented!(),
+            Error::CannotSpinoffCurrentBranch => f.write_str("Cannot spin-off current branch"),
+            Error::SpinoffBranchExists(new_branch_name) => f.write_fmt(format_args!(
+                "Cannot spin-off {new_branch_name}. It already exists"
+            )),
+            Error::DoesBranchExist(e) => {
+                f.write_fmt(format_args!("Couldn't check if branch exists: {}", e))
+            }
+            Error::GetBranchName(e) => f.write_fmt(format_args!("Couldn't get branch name: {}", e)),
+            Error::BaseCommitOid => f.write_str("Could not resolve OID of base commit"),
+            Error::UpstreamCommitOid => {
+                f.write_str("Could not resolve OID of upstream branch commit")
+            }
         }
     }
 }
