@@ -31,10 +31,13 @@ use std::{
     path::{Path, PathBuf},
     process::Command,
     rc::Rc,
+    sync::Arc,
     time::Duration,
 };
 use term::Term;
 
+use crate::config::Config;
+
 pub const LOG_FILE_NAME: &str = "gitu.log";
 
 //                                An overview of Gitu's ui and terminology:
@@ -76,14 +79,9 @@ pub const LOG_FILE_NAME: &str = "gitu.log";
 
 pub type Res<T> = Result<T, Error>;
 
-pub fn run(args: &cli::Args, term: &mut Term) -> Res<()> {
+pub fn run(config: Arc<Config>, args: &cli::Args, term: &mut Term) -> Res<()> {
     let dir = find_git_dir()?;
     let repo = open_repo(&dir)?;
-    let config = Rc::new(config::init_config(args.config.clone())?);
-
-    if config.general.mouse_support {
-        term.backend_mut().enable_mouse_capture()?;
-    }
 
     let mut app = app::App::create(
         Rc::new(repo),
