@@ -52,6 +52,7 @@ pub(crate) enum Op {
     AddRemote,
     Checkout,
     CheckoutNewBranch,
+    Spinoff,
     Delete,
     Commit,
     CommitAmend,
@@ -141,6 +142,7 @@ impl Op {
             Op::HalfPageDown => Box::new(editor::HalfPageDown),
             Op::Checkout => Box::new(branch::Checkout),
             Op::CheckoutNewBranch => Box::new(branch::CheckoutNewBranch),
+            Op::Spinoff => Box::new(branch::Spinoff),
             Op::Delete => Box::new(branch::Delete),
             Op::Commit => Box::new(commit::Commit),
             Op::CommitAmend => Box::new(commit::CommitAmend),
