@@ -2,11 +2,12 @@ use super::OpTrait;
 use crate::{
     Action,
     app::{App, State},
-    git::diff::PatchMode,
+    git::{self, diff::PatchMode},
+    gitu_diff::Status,
     item_data::ItemData,
     term::Term,
 };
-use std::{ffi::OsString, process::Command, rc::Rc};
+use std::{path::PathBuf, process::Command, rc::Rc};
 
 pub(crate) struct Unstage;
 impl OpTrait for Unstage {
@@ -14,7 +15,13 @@ impl OpTrait for Unstage {
         let action = match target {
             ItemData::AllStaged(_) => unstage_staged(),
             ItemData::Delta { diff, file_i } => {
-                unstage_file(diff.text[diff.file_diffs[*file_i].header.new_file.clone()].into())
+                let diff_header = &diff.file_diffs[*file_i].header;
+                let file_path = match diff_header.status {
+                    Status::Deleted => &diff_header.old_file,
+                    _ => &diff_header.new_file,
+                };
+
+                unstage_file(file_path.fmt(&diff.text).into_owned().into())
             }
             ItemData::Hunk {
                 diff,
@@ -60,14 +67,10 @@ fn unstage_staged() -> Action {
     })
 }
 
-fn unstage_file(file: OsString) -> Action {
+fn unstage_file(file: PathBuf) -> Action {
     Rc::new(move |app: &mut App, term: &mut Term| {
-        let mut cmd = Command::new("git");
-        cmd.args(["restore", "--staged"]);
-        cmd.arg(&file);
-
         app.close_menu();
-        app.run_cmd(term, &[], cmd)
+        app.run_cmd(term, &[], git::restore_index(&file))
     })
 }
 
