@@ -9,11 +9,7 @@ use crate::{
 };
 use git2::Repository;
 use ratatui::prelude::Size;
-use std::{
-    hash::Hash,
-    path::{Path, PathBuf},
-    rc::Rc,
-};
+use std::{hash::Hash, path::PathBuf, rc::Rc, sync::Arc};
 
 enum SectionID {
     RebaseStatus,
@@ -45,9 +41,9 @@ impl Hash for SectionID {
     }
 }
 
-pub(crate) fn create(config: Rc<Config>, repo: Rc<Repository>, size: Size) -> Res<Screen> {
+pub(crate) fn create(config: Arc<Config>, repo: Rc<Repository>, size: Size) -> Res<Screen> {
     Screen::new(
-        Rc::clone(&config),
+        Arc::clone(&config),
         size,
         Box::new(move || {
             let status = git::status(repo.workdir().ok_or(Error::NoRepoWorkdir)?)?;
@@ -55,10 +51,10 @@ pub(crate) fn create(config: Rc<Config>, repo: Rc<Repository>, size: Size) -> Re
                 .files
                 .iter()
                 .filter(|status| status.is_untracked())
-                .map(|status| Path::new(&status.path))
+                .map(|status| &status.path)
                 .collect::<Vec<_>>();
 
-            let untracked = items_list(&untracked_files);
+            let untracked = untracked_list(&untracked_files);
 
             let items = if let Some(rebase) = git::rebase_status(&repo)? {
                 vec![Item {
@@ -124,13 +120,13 @@ pub(crate) fn create(config: Rc<Config>, repo: Rc<Repository>, size: Size) -> Re
     )
 }
 
-fn items_list(files: &[&Path]) -> Vec<Item> {
+fn untracked_list(files: &[&String]) -> Vec<Item> {
     files
         .iter()
         .map(|path| Item {
             id: hash(path),
             depth: 1,
-            data: ItemData::File(path.to_path_buf()),
+            data: ItemData::Untracked(PathBuf::from(path)),
             ..Default::default()
         })
         .collect::<Vec<_>>()
