@@ -10,8 +10,8 @@ use crate::{
 use crossterm::event::{Event, KeyEvent, KeyModifiers, MouseButton, MouseEventKind};
 use git2::Repository;
 use ratatui::{Terminal, backend::TestBackend, layout::Size};
-use std::{path::PathBuf, rc::Rc, time::Duration};
-use temp_dir::TempDir;
+use regex::Regex;
+use std::{path::PathBuf, rc::Rc, sync::Arc, time::Duration};
 
 use self::buffer::TestBuffer;
 
@@ -30,53 +30,41 @@ macro_rules! snapshot {
 
 pub struct TestContext {
     pub term: Term,
-    pub dir: TempDir,
-    pub remote_dir: TempDir,
+    pub dir: PathBuf,
+    pub remote_dir: PathBuf,
     pub size: Size,
-    config: Rc<Config>,
+    config: Arc<Config>,
+}
+
+#[macro_export]
+macro_rules! setup_clone {
+    () => {{ TestContext::setup_clone(function_name!()) }};
 }
 
 impl TestContext {
-    pub fn setup_init() -> Self {
+    pub fn setup_clone(test_name: &str) -> Self {
         let size = Size::new(80, 20);
         let term = Terminal::new(TermBackend::Test {
             backend: TestBackend::new(size.width, size.height),
             events: vec![],
         })
         .unwrap();
-        let repo_ctx = RepoTestContext::setup_init();
+        let repo_ctx = RepoTestContext::setup_clone(test_name);
         Self {
             term,
             dir: repo_ctx.dir,
             remote_dir: repo_ctx.remote_dir,
             size,
-            config: Rc::new(config::init_test_config().unwrap()),
-        }
-    }
-
-    pub fn setup_clone() -> Self {
-        let size = Size::new(80, 20);
-        let term = Terminal::new(TermBackend::Test {
-            backend: TestBackend::new(size.width, size.height),
-            events: vec![],
-        })
-        .unwrap();
-        let repo_ctx = RepoTestContext::setup_clone();
-        Self {
-            term,
-            dir: repo_ctx.dir,
-            remote_dir: repo_ctx.remote_dir,
-            size,
-            config: Rc::new(config::init_test_config().unwrap()),
+            config: Arc::new(config::init_test_config().unwrap()),
         }
     }
 
     pub fn config(&mut self) -> &mut Config {
-        Rc::get_mut(&mut self.config).unwrap()
+        Arc::get_mut(&mut self.config).unwrap()
     }
 
     pub fn init_app(&mut self) -> App {
-        self.init_app_at_path(self.dir.path().to_path_buf())
+        self.init_app_at_path(self.dir.to_path_buf())
     }
 
     pub fn init_app_at_path(&mut self, path: PathBuf) -> App {
@@ -84,7 +72,7 @@ impl TestContext {
             Rc::new(Repository::open(path).unwrap()),
             self.size,
             &Args::default(),
-            Rc::clone(&self.config),
+            Arc::clone(&self.config),
             false,
         )
         .unwrap();
@@ -110,16 +98,19 @@ impl TestContext {
         };
         let mut debug_output = format!("{:?}", TestBuffer(backend.buffer()));
 
-        redact_temp_dir(&self.dir, &mut debug_output);
-        redact_temp_dir(&self.remote_dir, &mut debug_output);
+        redact(&mut debug_output, "From file://(.*)\n");
+        redact(&mut debug_output, "To file://(/.*)\n");
 
         debug_output
     }
 }
 
-fn redact_temp_dir(temp_dir: &TempDir, debug_output: &mut String) {
-    let text = temp_dir.path().to_str().unwrap();
-    *debug_output = debug_output.replace(text, &" ".repeat(text.len()));
+fn redact(debug_output: &mut String, regex: &str) {
+    let re = Regex::new(regex).unwrap();
+    if let Some(caps) = re.captures(debug_output) {
+        let c = caps.get(1).unwrap();
+        debug_output.replace_range(c.range(), &" ".repeat(c.len()));
+    }
 }
 
 pub fn keys(input: &str) -> Vec<Event> {
